Test Visiblity
open | ../tests/html/test_visibility.html |
verifyVisible | visibleParagraph |
verifyNotVisible | hiddenParagraph |
verifyNotVisible | suppressedParagraph |
verifyNotVisible | classSuppressedParagraph |
verifyNotVisible | jsClassSuppressedParagraph |
verifyNotVisible | hiddenSubElement |
verifyVisible | visibleSubElement |
verifyNotVisible | suppressedSubElement |
verifyNotVisible | jsHiddenParagraph |
assertFailureOnNext | true |
verifyNotVisible | visibleParagraph |
assertFailureOnNext | false |
verifyVisible | hiddenParagraph |
assertFailureOnNext | false |
verifyVisible | suppressedParagraph |
assertFailureOnNext | false |
verifyVisible | classSuppressedParagraph |
assertFailureOnNext | false |
verifyVisible | jsClassSuppressedParagraph |
assertFailureOnNext | false |
verifyVisible | hiddenSubElement |
assertFailureOnNext | false |
verifyVisible | suppressedSubElement |
assertFailureOnNext | false |
verifyVisible | jsHiddenParagraph |
assertErrorOnNext | Element nonExistentElement not found |
verifyVisible | nonExistentElement |